==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicDesktopIconUI__24BoundButton.h <==
// class javax.swing.plaf.basic.BasicDesktopIconUI$BoundButton

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7391d27632d03ad8 javax_swing_AbstractButton
// @dep_class 69f2be1043a99512 javax_swing_JButton
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 93dad58156cd28b9 javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton

// header file dependencies
// @dep_header javax_swing_JButton

#include "javax/swing/JButton.h"

#ifndef _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton_H_
#define _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_refs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$refs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vmethods	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtable	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtype	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method$_init$124b9c4e6e00855d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method$getMaximumSize$d24ee7fdb96c1fa3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method$getMinimumSize$f439289f02165af0(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method_info$getMaximumSize$d24ee7fdb96c1fa3;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method_info$getMinimumSize$f439289f02165af0;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method_info$getPreferredSize$4730bc91c97b24d9;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vmethods {
	struct _jc_java_awt_Dimension$object	*(*getMaximumSize$d24ee7fdb96c1fa3)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *);
	struct _jc_java_awt_Dimension$object	*(*getMinimumSize$f439289f02165af0)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *);
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_AbstractButton$vmethods	javax_swing_AbstractButton;
	_jc_javax_swing_JButton$vmethods	javax_swing_JButton;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vmethods	javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$refs {
    _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_refs	javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton;
    _jc_javax_swing_JButton$sub_refs	javax_swing_JButton;
    _jc_javax_swing_AbstractButton$sub_refs	javax_swing_AbstractButton;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_AbstractButton$sub_nonrefs	javax_swing_AbstractButton;
    _jc_javax_swing_JButton$sub_nonrefs	javax_swing_JButton;
    _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_nonrefs	javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object {
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtype _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicDesktopIconUI__24BoundButton.h <==
// class javax.swing.plaf.basic.BasicDesktopIconUI$BoundButton

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7391d27632d03ad8 javax_swing_AbstractButton
// @dep_class 69f2be1043a99512 javax_swing_JButton
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 3a055986ad98cfbe javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton

// header file dependencies
// @dep_header javax_swing_JButton

#include "javax/swing/JButton.h"

#ifndef _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton_H_
#define _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_refs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$refs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vmethods	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtable	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtype	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method$_init$124b9c4e6e00855d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method$getMaximumSize$d24ee7fdb96c1fa3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method$getMinimumSize$f439289f02165af0(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method_info$getMaximumSize$d24ee7fdb96c1fa3;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method_info$getMinimumSize$f439289f02165af0;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$method_info$getPreferredSize$4730bc91c97b24d9;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vmethods {
	struct _jc_java_awt_Dimension$object	*(*getMaximumSize$d24ee7fdb96c1fa3)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getMinimumSize$f439289f02165af0)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_AbstractButton$vmethods	javax_swing_AbstractButton;
	_jc_javax_swing_JButton$vmethods	javax_swing_JButton;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vmethods	javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$refs {
    _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_refs	javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton;
    _jc_javax_swing_JButton$sub_refs	javax_swing_JButton;
    _jc_javax_swing_AbstractButton$sub_refs	javax_swing_AbstractButton;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_AbstractButton$sub_nonrefs	javax_swing_AbstractButton;
    _jc_javax_swing_JButton$sub_nonrefs	javax_swing_JButton;
    _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$sub_nonrefs	javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$object {
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$vtype _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24BoundButton_H_ */
